@@ -20,7 +20,7 @@ class WatchmenStreamlitClient(object):
 		for indicator_data in indicator_list:
 			indicator_id = indicator_data["indicatorId"]
 			if indicator_id != "-1":
-				indicator = load_indicator_by_id(self.watchmen_client.token, indicator_data["indicatorId"])
+				indicator = load_indicator_by_id(self.watchmen_client.token,self.watchmen_client.host, indicator_data["indicatorId"])
 				self.indicators_dict[indicator["name"].upper()] = {"indicator": indicator, "node": indicator_data}
 
 	def load_achievement_by_id(self, achievement_id):
